# Motty, Mock your HTTP!
Motty is designed to build up the server mocking http protocol!

so. It will make you work **even though the server is not developed yet.**

You can readily make responses imitating restful standard.

![Main](../master/motty/app/static/images/github/main.png)

![View information](../master/motty/app/static/images/github/detail.png)


# Installation
You can easily install and run motty server by a few of commands.

## 1. Install python.
Python>=3.0 is required, so you should install python 3 before proceeding next step.

## 2. Set up an isolated environment.
> $ pip3 install virtualenv

> $ mkdir ~/mottyenv

> $ virtualenv ~/mottyenv

> $ source ~/mottyenv/bin/activate

## 3. Install motty.
> $ pip install motty

## 4. Run it! and play fun.
> $ run-motty
